<?php if(!defined('PLX_ROOT')) exit;
/**
 * PluXml Plugin StickyNotes class
 * @package	PLX
 * @version	1.1.1
 * @date	11/03/2019
 * @author	Thomas Ingles : sudwebdesign.free.fr
 **/
class StickyNotes extends plxPlugin {

	/**
	 * Constructeur de la classe StickyNotes
	 * @param	default_lang	langue par défaut utilisée par PluXml
	 * @return	void
	 * @author	Thomas Ingles
	 **/
	public function __construct($default_lang) {
		$this->release = '1.1.1';//$this->getInfo('version'); jamais appelé si en mode public (front-end)
		$this->lang = $default_lang;
		$this->default_lang = ( isset($_SESSION['lang_lang'])?$_SESSION['lang_lang'] : (isset($_SESSION['admin'])?$_SESSION['admin']:$default_lang) );//$_SESSION['admin_lang']:plx>=5.6
		parent::__construct($this->default_lang);# appel du constructeur de la classe plxPlugin (obligatoire) [avec la langue utilisateur]
		$this->href_plugin = (defined('PLX_GROOT') ? str_replace(PLX_ROOT,PLX_GROOT,PLX_PLUGINS) : PLX_PLUGINS).__CLASS__;//PLX_GROOT est pour le plugin gutuma
		$this->auth = $this->show = FALSE;

		if(isset($_SESSION['profil']) AND isset($_SESSION['user'])){#si connecté
			$this->auth = TRUE;
			$this->setConfigProfil(PROFIL_ADMIN);# droits pour accèder à la page config.php du plugin (PROFIL_MANAGER interdit #PLM) Même si autorisé ici (bog PLUXML?)
			//$this->setAdminProfil(PROFIL_ADMIN, PROFIL_MANAGER, PROFIL_MODERATOR, PROFIL_EDITOR, PROFIL_WRITER);# droits pour accèder à la page admin.php du plugin
# limite l'acces a l'ecran d'administration (editer les notes) du plugin de manière dynamique
			$se=array('PROFIL_ADMIN','PROFIL_MANAGER','PROFIL_MODERATOR','PROFIL_EDITOR','PROFIL_WRITER');
			$re=array(PROFIL_ADMIN, PROFIL_MANAGER, PROFIL_MODERATOR, PROFIL_EDITOR, PROFIL_WRITER);
			$acces = explode(',',str_replace($se,$re,$this->getParam('acces')));
			foreach($acces as $k => $ey)
				$acces[$k] = $ey+0;//INT
			if(in_array($_SESSION['profil'],$acces) && !in_array($_SESSION['user'],explode(',',$this->getParam('deny'))))
				$this->setAdminProfil((integer)$_SESSION['profil']);#Option pour autorisé le type de profil en dynamique. OU Alors PROFIL_ADMIN , PROFIL_MANAGER , PROFIL_MODERATOR , PROFIL_EDITOR , PROFIL_WRITER
		}

		# Déclarations des hooks
		if(!defined('PLX_ADMIN')){#pour la partie visiteur
			if(isset($_SESSION['profil']) OR !!$this->getParam('showInPublic')){
				$this->show = 'public';
				$this->addHook('Index', 'Index');// 1.0.6 active si bonne clef du site (racine) et utilisateur parm + connecté
				$this->addHook('showNotes', 'showNotes');#hooks utile ?

				$this->addHook('ThemeEndHead', 'ThemeEndHead');
				$this->addHook('ThemeEndBody', 'ThemeEndBody');
			}
		}else{#Et celle de la partie admin
			if(isset($_SESSION['profil'])){
				$this->show = 'admin';
				$this->addHook('AdminPrepend', 'AdminPrepend');// 1.0.6 active si bonne clef du site (racine) et utilisateur parm + connecté

				$this->addHook('AdminTopEndHead', 'ThemeEndHead');
				$this->addHook('AdminFootEndBody', 'ThemeEndBody');
				# Personnalisation du menu admin
				#$this->setAdminMenu($this->getInfo('title'), 1, $this->getInfo('description') . ' v' . $this->release . ' ' . $this->getInfo('date'));
				$this->setAdminMenu($this->getLang('L_NOTES'), 1, $this->getLang('L_DESCRIPTION') . PHP_EOL . $this->getInfo('title'). ' #' . $this->release . ' — ' . $this->getInfo('date'));
			}
		}
	}

	/**
	 * Méthode qui converti les urls contenus dans une chaine en liens cliquables. (de plx.utils v5.7)
	 *
	 * @param	string		chaîne d'entrée
	 * @param	string		Optionnel. Si spécifié, ce paramètre doit être un tableau associatif de format $arr['attribute'] = $value.
	 * @return	string		Retourne une copie de la chaîne str dont les urls ont été encapsulées dans des balises <a>.
	 * @author	http://code.seebz.net/p/autolink-php/
	 *	Exemple 1:
	 *		$str = 'A link : http://example.com/?param=value#anchor.';
	 *		$str = autolink($str);
	 *		echo $str; // A link : <a href="http://example.com/?param=value#anchor">http://example.com/?param=value#anchor</a>.
	 *  Exemple 2:
	 *		$str = 'http://example.com/';
	 *		$str = autolink($str, array("target"=>"_blank","rel"=>"nofollow"));
	 *		echo $str; // <a href="http://example.com/" target="_blank" rel="nofollow">http://example.com/</a>
	 **/
	public static function autolink($str, $attributes=array()) {
		$attrs = '';
		foreach ($attributes as $attribute => $value) {
			$attrs .= " {$attribute}=\"{$value}\"";
		}
		$str = ' ' . $str;
		$str = preg_replace('#([^"=\'>])((http|https|ftp)://[^\s<]+[^\s<\.)])#i', '$1<a href="$2"'.$attrs.'>$2</a>', $str);
		$str = substr($str, 1);
		return $str;
	}

	/** toggleDiv() is only in admin fixed by stickyToggleDiv
	 * Méthode qui Edite les notes
	 * @return	stdio
	 * @author	Thomas Ingles
	 **/
	public function editNotes($from='') {
		$imgbase = $this->href_plugin.'/img/';
		$togglex = '&nbsp;<a title="'.$this->getLang('L_HIDE_EXAMPLES_NOTES').' | '.$this->getLang('L_DISPLAY_EXAMPLES_NOTES').' '.$this->getLang('L_NOTES').'" id="toggler'.__CLASS__.'ex" href="javascript:void(0)" onclick="'."stickyToggleDiv(	'".__CLASS__."togglerex','toggler".__CLASS__."ex','≡','—','block');diese('toggler".__CLASS__."ex');".'" style="outline:none; text-decoration: none">≡</a>';
#CORE:
$data = $this->getParam('notes');
$current_md5 = md5($data);
if(isset($_POST['data'.__CLASS__])){
	if($_POST['page_md5'] == $current_md5){# good hash mismach
		//file_put_contents($this->datadir,stripslashes($_POST['data'.__CLASS__]));
		$this->setParam('notes', $_POST['data'.__CLASS__], 'cdata');
		$this->saveParams();
		$_SESSION['info'] = '#'.__CLASS__ . ' - ' . $this->getLang('L_NOTES') . ' ' . $this->getLang('L_SAVED') . '.';
		header('Location:'.$from);exit;
#		$data = $_POST['data'.__CLASS__];echo $this->lang('L_SAVED').".<br \>\n";$current_md5 = md5($_POST['data'.__CLASS__]);#memo
	}
	else {# hash mismach
		$_SESSION['error'] = '#'.__CLASS__ . ' - ' . $this->getLang('L_NOTES') . ' ' . $this->getLang('L_DIFF_HASH_INFO') . '.';
		#notification # Sorry, the current hash does not match the page hash.
		echo '<div class="warning" style="position:relative;text-align:left;background-color:#efefff;">';
		echo $this->getLang('L_SORRY') . '! ' . $this->getLang('L_DIFF_HASH_TEXT');
#toggleErrors lines?><hr />
<script type="text/javascript">
function toggleClass(name){
	var x = document.getElementsByClassName(name);
	for (var i = 0; i < x.length; i++) {
		if (x[i].style.display != "none")
			x[i].style.display = "none";
		else
			x[i].style.display = "initial";
	}
}
</script>
<a id="hideme<?php echo __CLASS__ ?>" class="button icon<?php echo __CLASS__ ?>" title="<?php $this->lang('L_TOGGLE_DIFF_TITLE'); ?>"
href='javascript:void((function(){toggleClass("hideme<?php echo __CLASS__ ?>");})())'
><img alt="<?php $this->lang('L_TOGGLE_DIFF'); ?> <?php echo __CLASS__ ?>" src="<?php echo $imgbase ?>diff.png"></a>
<?php
		echo '<b><span class="hideme' . __CLASS__ . '">' . $this->getLang('L_DIFF_LINES') . '</span><span class="hideme' . __CLASS__ . '" style="display:none">' . $this->getLang('L_DIFF') . '</span></b>&nbsp;:<br />' . PHP_EOL;#

		$current_data = explode(PHP_EOL,rtrim($data));
		$prev_data = explode(PHP_EOL,rtrim($_POST['data'.__CLASS__]));
		$diff = array_diff($prev_data,$current_data);
		foreach($diff as $kl => $line){
			echo '<span class="hideme' . __CLASS__ . '">#' . $kl . '←¶ </span><i class="error">' . $line . '</i><br />' . PHP_EOL;
			echo '<span class="hideme' . __CLASS__ . '">#' . $kl . '→¶ <i class="success">' . (isset($current_data[$kl])?$current_data[$kl]:$this->getLang('L_NOTHING')) . '</i><hr /></span>' . PHP_EOL;#@ Fix New lines Notice: Undefined offset :)
		}
		echo '<br />' . $this->getLang('L_DIFF_NFO1_TEXT') . (empty($diff)?'':'<br />' . $this->getLang('L_DIFF_NFO2_TEXT')) . '</div>';
#go to warning message ?>
<script>window.setTimeout(function(){window.location.hash='top';},3333);</script>
<?php
	}# FI good hash mismach
}# FI post data
#CORE;
?>
<script type="text/javascript">
function submitEdit(){
 document.getElementById('save<?php echo __CLASS__ ?>').value ="<?php $this->lang('L_SAVING'); ?>...";
}
</script>
<p><?php $this->lang('L_CCM');echo $togglex; ?></p><br />
<pre id="<?php echo __CLASS__ ?>togglerex" style="display:none;"><hr /><?php echo htmlspecialchars($this->getLang('L_EXAMPLES').PHP_EOL.'[!][@][<'.$this->getLang('L_CATE').'>:]<'.$this->getLang('L_TEXT').'>',ENT_NOQUOTES,PLX_CHARSET); ?></pre>
<hr style="margin-bottom: 2.5rem;" />
<a id="saver<?php echo __CLASS__ ?>" class="button update green icon<?php echo __CLASS__ ?>" title="<?php $this->lang('L_SAVE_TITLE') ?>"
href='javascript:void((function(){document.getElementById("edit<?php echo __CLASS__ ?>").submit();})())'
><img alt="<?php $this->lang('L_SAVE'); ?> <?php echo __CLASS__ ?>" src="<?php echo $imgbase ?>publish.png"></a>
<a id="reseter<?php echo __CLASS__ ?>" class="button orange icon<?php echo __CLASS__ ?>" title="<?php $this->lang('L_RESET') ?> <?php $this->lang('L_THE_NOTES') ?>"
href='javascript:void((function(){document.getElementById("reset<?php echo __CLASS__ ?>").click();})())'
><img alt="<?php $this->lang('L_RESET'); ?> <?php echo __CLASS__ ?>" src="<?php echo $imgbase ?>reset.png"></a>
<a id="clearer<?php echo __CLASS__ ?>" class="button icon<?php echo __CLASS__ ?>" title="<?php $this->lang('L_CLEAR_TITLE') ?>"
href='javascript:void((function(){document.getElementById("clear<?php echo __CLASS__ ?>").click();})())'
><img alt="<?php $this->lang('L_CLEAR'); ?> <?php echo __CLASS__ ?>" src="<?php echo $imgbase ?>clear.png"></a>
<a id="backuper<?php echo __CLASS__ ?>" class="button blue icon<?php echo __CLASS__ ?>" title="<?php $this->lang('L_BACKUP_TITLE') ?>"
href='javascript:void((function(){
var%20stck="<?php echo $this->getLang('L_BACKUP').' '.__CLASS__.': ('.$this->getLang('L_NOTES').' '.$this->getLang('L_BACKUP_TXT').' '.date($this->getLang('L_BACKUP_DATE')) ?>)\n"+document.getElementById("data<?php echo __CLASS__ ?>").value;
uriContent="data:application/octet-stream;filename=<?php echo __CLASS__.'_'.date('Y-m-d_H-m') ?>.txt%27,"+encodeURIComponent(stck);newWindow=window.open(uriContent,"<?php echo __CLASS__.'_'.date('Y-m-d_H-m') ?>.txt");return%20false;})())'
><img alt="<?php $this->lang('L_BACKUP'); ?> <?php echo __CLASS__ ?>" src="<?php echo $imgbase ?>backup.png"></a>

<form action="" id="edit<?php echo __CLASS__ ?>" class="<?php echo __CLASS__ ?>" method="post">
<textarea id="data<?php echo __CLASS__ ?>" name="data<?php echo __CLASS__ ?>"><?php echo stripslashes($data) ?></textarea>
<input type="hidden" name="page_md5" value="<?php echo $current_md5; ?>" />
<br /><a id="<?php echo __CLASS__ ?>ManagerBookmark" title="Ctrl+d ;)" href="?p=<?php echo __CLASS__ ?>&amp;<?php echo __CLASS__ ?>Manager=1"><img alt="<?php $this->lang('L_EDIT') ?> " src="<?php echo $imgbase ?>bookmark.png"><?php echo __CLASS__ ?></a>
<div class="in-action-bar" style="z-index:1;">
	<button class="update green icon<?php echo __CLASS__ ?>" type="submit" id="save<?php echo __CLASS__ ?>" value="o" onClick="return submitEdit()" title="<?php $this->lang('L_SAVE_TITLE') ?>"><img src="<?php echo $imgbase ?>publish.png"><span class="sml-hide med-show-inline"><?php $this->lang('L_SAVE'); ?></span></button>
	<button class="orange icon<?php echo __CLASS__ ?>" type="reset" id="reset<?php echo __CLASS__ ?>" name="reset" value="o" onClick='if(!confirm("<?php $this->lang('L_RESET') ?>"))return false;' title="<?php $this->lang('L_RESET') ?> <?php $this->lang('L_THE_NOTES') ?>"><img src="<?php echo $imgbase ?>reset.png"><span class="sml-hide med-show-inline"><?php $this->lang('L_RESET') ?></span></button>
	<button class="icon<?php echo __CLASS__ ?>" id="clear<?php echo __CLASS__ ?>" name="clear" value="o"
 onClick='if(confirm("<?php $this->lang('L_CLEAR_TITLE'); ?>"))document.getElementById("data<?php echo __CLASS__ ?>").value="";return false;' title="<?php $this->lang('L_CLEAR_TITLE') ?>"><img src="<?php echo $imgbase ?>clear.png"><span class="sml-hide med-show-inline"><?php $this->lang('L_CLEAR') ?></span></button>
	<button class="blue icon<?php echo __CLASS__ ?>" id="backup<?php echo __CLASS__ ?>" name="backup" value="o" onClick="getElementById('backuper<?php echo __CLASS__ ?>').click();return false;" title="<?php $this->lang('L_BACKUP_TITLE') ?>"><img src="<?php echo $imgbase ?>backup.png"><span class="sml-hide med-show-inline"><?php $this->lang('L_BACKUP') ?> (txt)</span></button>
	<br class="med-hide" />
	<small><?php $this->lang('L_HASH') ?>: <?php echo $current_md5 ?></small>
</div>
</form>
<?php
	}#FI editNotes
	/**
	 * Méthode qui Affiche les notes #ThemeEndBody
	 * @return	stdio
	 * @author	Thomas Ingles
	 **/
	public function showNotes() {
		$PROFIL = array((isset($_SESSION['profil']) AND $this->auth )?!!$this->getAdminProfil():FALSE);// edit menu
		$PROFIL[] = (isset($_SESSION['profil']) AND $this->auth )?in_array($_SESSION['profil'],$this->getConfigProfil()):FALSE;// config menu
		$imgbase = $this->href_plugin.'/img/';
		$dspltxt = !$this->getParam('display')?'≡':'—';
		$dspltoggle = '';#moreSimply 'inline-table';#simply //!$this->getParam('valign')?($this->getParam('halign')?'inline-table':'block'):'grid';//inline-table OR block
		$toggler = '<a title="'.$this->getLang('L_TOGGLE').' '.$this->getLang('L_THE_NOTES').' ('.$this->getLang('L_HIDE').'/'.$this->getLang('L_DISPLAY').')" id="toggler'.__CLASS__.'" href="javascript:void(0)" onclick="'."if(stickyToggleDiv('".__CLASS__."toggler','toggler".__CLASS__."','≡','—','".$dspltoggle."')){diese('".__CLASS__."displace');}else{diese('top');}".'">'.$dspltxt.'</a>';
#		$this->show ? isset($_SESSION['profil']) $this->show=='public'
		$plxpage = explode('/',$_SERVER['PHP_SELF']);
		$plxpage = end($plxpage);
//~		$editatr = 'href="javascript:void(0)" onclick="' . __CLASS__ . 'Manager.openPopup(\''.L_MEDIAS_TITLE.'\', true)"';
		$editatr = 'href="javascript:void(0)" onclick="' . __CLASS__ . 'Manager.openPopup(\''.__CLASS__.'\', true)"';
		if($plxpage == 'plugin.php' AND $_GET['p'] == __CLASS__ ){#admin.php
			$editatr = 'href="#top"';# var_dump(__CLASS__,__FUNCTION__,$PROFIL,$plxpage,$_GET['p'],$_SERVER['PHP_SELF'],$_SERVER,$this);
		}
		$edit = ''. $PROFIL[0] ? '<a title="'.$this->getLang('L_EDIT').'" id="edit_'.__CLASS__.'_link" '.$editatr.'><img alt="'.$this->getLang('L_EDIT').'" src="'.$imgbase.'admin.png"></a><br />' : '';
#$this->getParam('')?'':'';
#$showInPublic = $this->getParam('showInPublic')?'':'';

		$hAlign = explode(' ','center right left');
		$halign = ' '.$hAlign[(int) $this->getParam('halign')];
		$valign = $this->getParam('valign')?' vertical':' horizontal';
  
		$fsize = 'font-size:' . $this->getParam('fsize') . '%;';
		$fsizez = 'font-size:' . $this->getParam('fsizez') . '%;';
		$size = $this->getParam('size')*2;
		$zoom = 1.01 + ($this->getParam('zoom')/10);
#		$zook = (float)'1.'. $zoom.'1';
		$padd = $this->getParam('pad');
		$pad = 'padding:' . ($padd / 4).'rem ' . ($padd / 2) . 'rem ' . ($padd / 2) . 'rem ' . ($padd / 4) . 'rem;';
		$marg = $this->getParam('mar');
		$mar = 'margin:' . ($marg / 4) . 'rem;';

		$goodspace = ($size/3)*$zoom;
		$space = 'padding:' . $goodspace . 'rem;';

		$style = 'height:' . $size . 'rem;width:' . $size . 'rem;' . $pad . $mar;#''.$fsize;
		$display = $this->getParam('display') ? '' : 'display:none;';
#		menu
		$hmenu = $this->getParam('hmenu') ? ' right': ' left';
		$vmenu = $this->getParam('vmenu') != 2 ? 'bottom:1rem;' : 'top:16.18rem;';
		$amenu = !$this->getParam('halign') ? array('left', 'right') : ($this->getParam('halign') == 2 ? array('left', 'right') : array('right', 'left'));#menu auto
		$amenu = !$this->getParam('hmenu') ? $amenu : ($this->getParam('hmenu') == 2 ? array('right','left') : $amenu/*array('left','right')*/);
		$ulCls = (!$this->getParam('valign') ? 'sml-12'.(($this->show == 'admin')?' section med-9 med-offset-3 lrg-10 lrg-offset-2':''):'sml-3');#ul css class in admin only (offset's rem by js)
#css dynamique
?>
<style style="dispay:none">
#StickyNotestoggler{
 margin-top: <?php echo (int)($this->getParam('mars')) ?>rem !important;
}
ul.StickyNotes li span:hover,ul.StickyNotes li span:focus{
 -webkit-transform: scale(<?php echo $zoom ?>);
 -moz-transform: scale(<?php echo $zoom ?>);
 -o-transform: scale(<?php echo $zoom ?>);
 transform: scale(<?php echo $zoom ?>);
 <?php echo $fsizez ?>
}
ul.StickyNotes li span{
 <?php echo $fsize.$style ?>
}
#StickyNotesMenu {
 <?php echo $amenu[1] ?>: 0;
 <?php echo $vmenu ?>
 text-align: <?php echo $amenu[0] ?>
}
</style>
<?php
$togglePanel = '<span id="hidePanel' . __CLASS__ . '" class="button icon'. __CLASS__ .'" title="'.$this->getLang('L_TOGGLE').' '.$this->getLang('L_THE_NOTES').' ('.$this->getLang('L_HIDE').'/'.$this->getLang('L_DISPLAY').') #Panel"
onclick=\'stickyTogglePanel("' . __CLASS__ . 'ThePanel","hidePanel' . __CLASS__ . '","≡","—","none");\'>≡</span>&nbsp;';

$toggleNotes = '';
if(isset($_SESSION['profil']) AND $this->auth){
 $toggleNotes = '<span id="hideadmin' . __CLASS__ . '" class="button icon'. __CLASS__ .'" title="'.$this->getLang('L_TOGGLE').' '.$this->getLang('L_THE_NOTES').' ('.$this->getLang('L_HIDE').'/'.$this->getLang('L_DISPLAY').') #Admin"
onclick=\'stickyToggleClass("adminnote");\'
>A</span>&nbsp;<span id="hidepublic' . __CLASS__ . '" class="button icon'. __CLASS__ .'" title="'.$this->getLang('L_TOGGLE').' '.$this->getLang('L_THE_NOTES').' ('.$this->getLang('L_HIDE').'/'.$this->getLang('L_DISPLAY').') @Public "
onclick=\'stickyToggleClass("publicnote");\'
>@</span>&nbsp;';
}
$displaceIt = !0;
$displace = '<span id="before' . __CLASS__ . '" class="' . ($displaceIt? __CLASS__ . 'displace" title="' . $this->getLang('L_NOTES') . ' ' . $this->getLang('L_DISPLACE') . '">&nbsp;<div>' . $this->getLang('L_NOTES') . '&nbsp;' . $this->getLang('L_DISPLACE').'</div>' : '">&nbsp;') . $togglePanel . $toggleNotes . '</span>';#anchor to go to
?>
	<div class="<?php echo ($this->getParam('valign')?'grid':'col '.$ulCls) ?>" id="<?php echo __CLASS__ ?>Panel">
<div class="<?php echo ($this->getParam('valign')?'col '.$ulCls.' Vertic':'Horizon') ?>al" id="<?php if($displaceIt) echo __CLASS__.'displace' ?>" title="<?php if($displaceIt) echo $this->getLang('L_NOTES') . ' ' . $this->getLang('L_DISPLACE') ?>">
		<ul class="<?php echo  __CLASS__ . $halign . $valign?>" id="<?php echo __CLASS__ ?>toggler" style="<?php echo $display.$fsize.$space ?>">
		<?php echo $displace ?><span id="<?php echo __CLASS__ ?>ThePanel">
<?php
$colors = explode(' ','c0c0ff c0ffc0 c0ffff ffc0c0 ffc0ff c8c8ff c8ffc8 c8ffff ffc8c8 ffc8ff ceceff ceffce ceffff ffcece ffceff ffffc fff');#ce&c0 #17 colors #rem : yellows -> ffffc0 ffffe : v1.0.8
$notes = $cats = array();
$tot = 0;#count StickyNotes
#foreach(explode("\n",rtrim(file_get_contents("data"))) as $note)
#foreach(explode("\n",rtrim($this->datadir)) as $note)
foreach(explode(PHP_EOL,rtrim($this->getParam('notes'))) as $note)
	$notes[] = $note;
if($halign=='right') $notes = array_reverse($notes);//float right
foreach($notes as $note){
	if(!isset($note[1]))#empty($note) : have \n
		continue;
	if($note[0]!="!"){
		#PUBLIC NOTES WITH @
		if(!$this->auth){
			if($note[0]!="@") continue;
			else $note = ltrim($note,'@');
		}
		$tot++;
		$temp = explode(":",$note);
		if(count($temp) > 1){
			$c_cat = array_shift($temp);
			if(!array_key_exists($c_cat,$cats)){
				$cats[$c_cat] = count($cats);
			}
			$text = implode(":",$temp);
		} else {
			$c_cat = "";
			$text = $note;
		}
		$color = @$colors[$cats[$c_cat]];
		$tdisp = (!empty($c_cat)?'': ' style="display:none"');
//la note &#x2197; == ↗ ?>
			<li>
				<span draggable="false" style="background-color:#<?php echo $color ?>" class="<?php echo ($note[0]!="@")?'admin':'public';?>note"><i draggable="false"><img draggable="false" title="Click == Ctrl + c" class="<?php echo __CLASS__ ?>copier" src="<?php echo $imgbase?>copier.png">#<?php echo $tot ?></i><h2 draggable="false"<?php echo $tdisp ?>>#<?php echo $c_cat ?> </h2><p draggable="false"><?php echo self::autolink( htmlentities($text), array('referer'=>'noreferer','target'=>'_blank','title'=>'↦↗','draggable'=>'false','onclick'=>'event.stopPropagation();') ) ?></p></span>
			</li>
<?php
	}
}
$zeroNote = (!$tot?''.$tot . ' ' . $this->getLang('L_NOTES').'<br />':'');#zéro note
?></span><!-- ThePanel -->
			<div id="<?php echo __CLASS__ ?>after"><?php echo $zeroNote ?><sub><sup>#<a href="http://sudwebdesign.free.fr"><?php echo __CLASS__ ?></a></sup></sub></div>
		</ul><!-- ul <?php echo __CLASS__ ?>toggler -->

	</div>
		<ul class="<?php echo  __CLASS__ ?> outer" id="<?php echo __CLASS__ ?>outer" title="<?php echo $this->getLang('L_NOTES') . ' ' . $this->getLang('L_DISPLACE') ?>"></ul><!-- ul <?php echo __CLASS__ ?> outer -->
		<span id="<?php echo __CLASS__ ?>Menu" class="<?php echo __CLASS__ ?>"><!-- menu -->
		<a title="<?php $this->lang('L_RELOAD_TITLE'); echo $displaceIt ? PHP_EOL . $this->getLang('L_RESTORE_POS') : ''; ?>" href="" onclick="sessionStorage.clear();"><img alt="<?php $this->lang('L_RELOAD') ?>" src="<?php echo $imgbase?>reload.png"></a><br />
		<span id="edit_<?php echo __CLASS__ ?>"><i><?php echo ( (!$PROFIL[1]) ?'':'<a title="'.$this->getLang('L_PLUGIN_CONFIG_TITLE').' '.__CLASS__.'" href="'.PLX_CORE.'admin/parametres_plugin.php?p='.__CLASS__.'#top"><img alt="'.$this->getLang('L_PLUGIN_CONFIG').' '.__CLASS__.'" src="'.$imgbase.'settings.png"></a><br />') ?></i></span><i><?php echo $edit ?></i><i><?php echo $toggler ?></i><br /><a id="<?php echo __CLASS__ ?>goto" title="<?php $this->lang('L_VIEW') ?> <?php $this->lang('L_THE_NOTES') ?>. #<?php echo $tot ?> <?php $this->lang('L_NOTES') ?>" href="#<?php echo __CLASS__ ?>displace" onClick="if(window.location.hash!='#<?php echo __CLASS__?>displace'){ this.href='#<?php echo __CLASS__?>displace';} else {this.href='#top';} if(document.getElementById('<?php echo __CLASS__ ?>toggler').style.display=='none') document.getElementById('toggler<?php echo __CLASS__ ?>').click();"><i>#<?php echo $tot ?></i></a><br /><i id="<?php echo __CLASS__ ?>powa">#<a href="http://sudwebdesign.free.fr"><?php echo __CLASS__ ?></a></i></span>
	</div>
<textarea id="<?php echo __CLASS__ ?>copier" style="display:none;"></textarea>
<?php
		$isManager = isset($_GET[__CLASS__.'Manager']);
		if(!$isManager){#si vient de auth : avec &amp;StickyNotesManager=1 ;)
			$isManager = (isset($_SERVER['HTTP_REFERER']) AND strpos($_SERVER['HTTP_REFERER'], ';'.__CLASS__.'Manager')) ? !0 : $isManager;
			if($isManager){#referer == change form action pour garder le Manager si publié ?>
<script style="dispay:none">document.getElementById('edit<?php echo __CLASS__ ?>').action=window.location+'&<?php echo __CLASS__ ?>Manager=1';</script>
<?php			}#fi referer
 		}

		if($isManager){# editNotes in popup Manager + css rule to hide aside
?>
<style style="dispay:none">
.aside, #<?php echo __CLASS__ ?>ManagerBookmark {
	display: none;
}
.section .action-bar {
	left: 0;
	right: 0;
	margin-right: 0;
	margin-left: 0;
}
@media (min-width: 768px) {
	.col.lrg-offset-2 {
		margin-left: 10px;
		margin-right: 20px;
		width: 100%;
	}
}
</style>
<script style="dispay:none">
	//stackoverflow.com/a/36108449 : onload chained
	if(window.onload != null){var fsnm = window.onload;}
	window.onload=function(){//restore rules
		//console.log('#<?php echo __CLASS__.'->'.__FUNCTION__ . ' ' . $this->getParam('display') ?> #window.onload', document.getElementById('<?php echo __CLASS__ ?>toggler').style.display)
		if(document.getElementById('<?php echo __CLASS__ ?>toggler').style.display != 'none')
			document.getElementById('toggler<?php echo __CLASS__ ?>').click();// simulate click to hide it if need it for POPUP Notes Manager
		try{//hide plxAdminBar
			document.getElementById('plxadminbar').style.display = 'none';//hide bar
			new Array('-nocache','-icon','').forEach(function(e){//plxadminbar links
				var ab_css = document.getElementById('plxadminbar'+e+'-css');//link id
				ab_css.parentNode.removeChild(ab_css);//remove
			});
		}catch(e){if(console)console.log('#<?php echo __CLASS__ ?>Manager : hide plxAdminBar error: '+e,e)}
		if(fsnm!=null){fsnm();}//chained onload
	}
</script>
<?php
		}#Manager
	}#showNotes()
	/**
	 * Méthode qui Est la 1ere appelée :) 
	 * @return	void
	 * @author	Thomas Ingles
	 **/
	public function plxMotorConstruct() {//#tep #unused V 1.0.6 Pour être sur qu'il s'agit du bon site (MULTILUXML IN SAME HOST) * @author Thomas Ingles
echo '<?php '; ?>
			#if (!defined('racine<?php echo __CLASS__ ?>'))define('racine<?php echo __CLASS__ ?>', $this->aConf['racine']);//clef du moment
			#$_SESSION['racine<?php echo __CLASS__ ?>'] = $this->aConf['racine'];//clef
?><?php
	}
	public function OnActivate(){# Méthode appelée quand on active le plugin
		#Paramètres par défaut
		if(!is_file($this->plug['parameters.xml'])) {
			$data = @file_get_contents(PLX_PLUGINS.__CLASS__."/data/".$this->default_lang);//get data-Lang file
			if(!$data) $data = @file_get_contents(PLX_PLUGINS.__CLASS__."/data/data");//If No Lang get basic data file
#			$data = mb_convert_encoding($data, 'HTML-ENTITIES', PLX_CHARSET);//stackoverflow.com/a/15183803
			$data = html_entity_decode($data);
			$this->setParam('notes', 'ChuckNorris:'.$this->getLang('L_1ST_NOTES').' ;)'.($data?PHP_EOL.$data:'').PHP_EOL.$this->getLang('L_1ST_NOTES_EXAMPLES').' ;)', 'cdata');
#			default
			$this->setParam('acces', 'PROFIL_ADMIN, PROFIL_MANAGER, PROFIL_MODERATOR, PROFIL_EDITOR', 'string');
			$this->setParam('deny', '', 'string');
			$this->setParam('showInPublic', 0, 'numeric');
			$this->setParam('display', 1, 'numeric');
			$this->setParam('hmenu', 0, 'numeric');
			$this->setParam('vmenu', 0, 'numeric');
			$this->setParam('halign', 0, 'numeric');
			$this->setParam('valign', 1, 'numeric');
			$this->setParam('fsizez', 100, 'numeric');
			$this->setParam('fsize', 100, 'numeric');
			$this->setParam('size', 10, 'numeric');
			$this->setParam('zoom', 9, 'numeric');
			$this->setParam('pad', 3, 'numeric');
			$this->setParam('mar', 2, 'numeric');
			$this->saveParams();
		}
		$plxMotor = plxMotor::getInstance();
		$_SESSION['racine'.__CLASS__] = $plxMotor->aConf['racine'];//clef
	}
	public function OnDeactivate(){# Méthode appelée quand on desactive le plugin
		unset($_SESSION['racine'.__CLASS__]);//clef supprimée
	}
	public function OnUpdate(){# Méthode appelée quand on update le plugin (si fichier update présent a la racine du plugin)
		$data = @file_get_contents(PLX_PLUGINS.__CLASS__."/data/".$this->default_lang);//get update data-Lang file
		if(!$data) $data = @file_get_contents(PLX_PLUGINS.__CLASS__."/data/data");//If No Lang get update basic data file
#		$data = mb_convert_encoding($data, 'HTML-ENTITIES', PLX_CHARSET);//stackoverflow.com/a/15183803
		$data = html_entity_decode($data);
		$this->setParam('notes', 'ChuckNorris:Say #'.__CLASS__.' '.$this->getLang('L_UPDATED').($data?PHP_EOL.$data:'').PHP_EOL.$this->getParam('notes'), 'cdata');#Import update Notes
		$plxMotor = plxMotor::getInstance();
		$_SESSION['racine'.__CLASS__] = $plxMotor->aConf['racine'];//clef
	}
	public function AdminPrepend(){//#tep V 1.0.6 Pour être sur qu'il s'agit du bon site (MULTIPLE PLUXML IN SAME HOST) * @author Thomas Ingles
echo '<?php '; ?>
		if(!defined('PLX_AUTHPAGE') OR PLX_AUTHPAGE !== true){ # si on est ds admin et pas sur la page de login
			$_SESSION['racine<?php echo __CLASS__ ?>'] = $plxAdmin->aConf['racine'];# clef de l'admin
		}
?><?php
	}
	public function Index(){//#tep² V 1.0.6 Pour être sur qu'il s'agit du bon site (Multipluxml in same (local)host) * @author Thomas Ingles
		$racine = 'racine'.__CLASS__;//name (clef)
echo '<?php #'.__CLASS__.PHP_EOL; ?>
		if(!isset($_SESSION['<?php echo $racine ?>'])){
			$plxMotor->plxPlugins->aPlugins['<?php echo __CLASS__ ?>']->auth = FALSE;
		}else{
			if ($plxMotor->aConf['racine'] != $_SESSION['<?php echo $racine ?>']){//clef différente
				$plxMotor->plxPlugins->aPlugins['<?php echo __CLASS__ ?>']->auth = FALSE;
			}
		}
?><?php
	}
	public function ThemeEndHead(){?>
<link id="<?php echo __CLASS__ ?>-css" defer rel="stylesheet" type="text/css" href="<?php echo $this->href_plugin ?>/css/<?php echo __CLASS__ ?>.css?v=<?php echo $this->release ?>" media="screen,print" />
<?php
	}
	public function ThemeEndBody(){
		$this->showNotes();
		$this->adminjs();
	}
	public function adminJs(){#in ThemeEndBody
?>
<script type="text/javascript" id="<?php echo __CLASS__ ?>-js" src="<?php echo $this->href_plugin ?>/js/<?php echo __CLASS__ ?>.js?v=<?php echo $this->release ?>"></script>
<script type="text/javascript">
	<?php echo __CLASS__ ?>Manager.construct({
		windowName : "<?php echo $this->getLang('L_EDIT').' ('.__CLASS__.')' ?>",
		racine:	"<?php echo plxUtils::getRacine() ?>",
		urlManager: "core/admin/plugin.php?p=<?php echo __CLASS__ ?>&<?php echo __CLASS__ ?>Manager=1"
	});
</script>
<?php
		$this->displaceJs();
	}
	public function displaceJs(){#in adminJs to ThemeEndBody
?>
<script type="text/javascript" id="displace-js" src="<?php echo $this->href_plugin ?>/js/displace.min.js?v=124"></script>
<script type="text/javascript">
const <?php echo __CLASS__ ?>outer = document.getElementById('<?php echo __CLASS__ ?>outer');//outer Panel document.querySelector('#<?php echo __CLASS__ ?>outer');
function setDisplace(individual) {

	const <?php echo __CLASS__ ?>displaceJsoptions = {
		onMouseDown: <?php echo __CLASS__ ?>,
		onTouchStart: <?php echo __CLASS__ ?>,
		onMouseUp: <?php echo __CLASS__ ?>Pos,
		onTouchStop: <?php echo __CLASS__ ?>Pos,
//		relativeTo: document//.body
//		constrain: true
	};

	const <?php echo __CLASS__ ?>displaceJsel = document.querySelectorAll('#<?php echo __CLASS__ ?>toggler li');//notes  StickyNotestoggler (horizontal & vertical)
	const <?php echo __CLASS__ ?>displaceJsTab = document.getElementById('<?php echo __CLASS__ ?>displace');//Panel document.querySelector('#<?php echo __CLASS__ ?>displace');
	const <?php echo __CLASS__ ?>displaceJsTaboptions = {
//		handle: document.getElementById('before<?php echo __CLASS__ ?>'),//Grabber with img or all moves
		onMouseDown: <?php echo __CLASS__ ?>Active,
		onTouchStart: <?php echo __CLASS__ ?>Active,
		onMouseUp: <?php echo __CLASS__ ?>Inactive,
		onTouchStop: <?php echo __CLASS__ ?>Inactive
	};
	const <?php echo __CLASS__ ?>displaced = [];

	<?php echo __CLASS__ ?>displaced.push(displacejs(<?php echo __CLASS__ ?>displaceJsTab, <?php echo __CLASS__ ?>displaceJsTaboptions))
	if (sessionStorage.getItem('<?php echo __CLASS__ ?>Displace')){
		document.getElementById('<?php echo __CLASS__ ?>displace').style.cssText = sessionStorage.getItem('<?php echo __CLASS__ ?>Displace');
	}

	for(var i = 0; i < <?php echo __CLASS__ ?>displaceJsel.length; i++) {
		<?php echo __CLASS__ ?>displaced.push(displacejs(<?php echo __CLASS__ ?>displaceJsel[i], <?php echo __CLASS__ ?>displaceJsoptions));
		<?php echo __CLASS__ ?>displaceJsel[i].id = '<?php echo __CLASS__ ?>'+i;
		var tempos = sessionStorage.getItem(<?php echo __CLASS__ ?>displaceJsel[i].id);
		if(tempos){
			var inPanel = document.createElement("DIV");
			inPanel.className = 'inPanel';
			inPanel.title = "→≡\↵";// Return in Panel
			inPanel.onclick = function(el){in<?php echo __CLASS__ ?>(el);};
			<?php echo __CLASS__ ?>displaceJsel[i].setAttribute('style', tempos);
			<?php echo __CLASS__ ?>displaceJsel[i].setAttribute('class', '<?php echo __CLASS__ ?>Fixed');
			<?php echo __CLASS__ ?>outer.appendChild(<?php echo __CLASS__ ?>displaceJsel[i]);//goto ul outer of panel
			<?php echo __CLASS__ ?>displaceJsel[i].insertBefore(inPanel, <?php echo __CLASS__ ?>displaceJsel[i].childNodes[0]);//pined rounded top img
		}else{
			<?php echo __CLASS__ ?>displaceJsel[i].style.position = 'initial';//relative
		}
	}
	return <?php echo __CLASS__ ?>displaced;
}
const <?php echo __CLASS__ ?>displaced = setDisplace();
function <?php echo __CLASS__ ?>(el,event){
	var rect = el.getBoundingClientRect();// #v 1.1.0 ok on touch & click !work fine @begining of funk //duckduckgo.com/?t=lm&q=position+of+an+element&ia=web
	el.style.zIndex = '7';
	if(el.style.position != 'fixed'){//1st time to move outer box
		try{event.stopPropagation();}catch(e){console.log(e,'<?php echo __CLASS__ ?> : error no stopPropagation');}//v 1.0.8
		el.style.position = 'fixed';//absolute
		el.className = '<?php echo __CLASS__ ?>Moved firsttime';// v 1.0.10
		el.style.left = rect.left+'px'// #v 1.1.0
		el.style.top = rect.top+'px';// #v 1.1.0
		var inPanel = document.createElement("DIV");
		inPanel.className = 'inPanel';
		inPanel.title = "→≡\↵";// Return in Panel
		el.insertBefore(inPanel, el.childNodes[0]);//Add div for icon to return in panel
		<?php echo __CLASS__ ?>outer.appendChild(el);//goto ul (outer of panel)
	}else{// v 1.0.10
		el.className = '<?php echo __CLASS__ ?>Moved';
	}
}
function <?php echo __CLASS__ ?>Pos(el,event){
	var rect = el.getBoundingClientRect();// #v 1.1.0 ok on touch & click !work fine @begining of funk //duckduckgo.com/?t=lm&q=position+of+an+element&ia=web
	if(el.className == '<?php echo __CLASS__ ?>Moved firsttime'){//v 1.0.10
		el.style.left = rect.left+'px';// #v 1.1.0 in <?php echo __CLASS__ ?>()
		el.style.top = rect.top+'px';// #v 1.1.0 in <?php echo __CLASS__ ?>()
	}
//Moving a DIV element to bottom of parent (as last child) stackoverflow.com/a/3415533
	el.className = '<?php echo __CLASS__ ?>Fixed';
	el.parentNode.appendChild(el);//always last is on top at the bottom of dom (last element)//1.0.7
	el.style.zIndex = '2';//initial
	sessionStorage.setItem(el.id, el.style.cssText);//save rules
	if(event.target.className == 'inPanel'){//div.inPanel click return to panel #tep ok in chr 31 // v1.0.8
		in<?php echo __CLASS__ ?>(event);
		return;
	}
}
function <?php echo __CLASS__ ?>Active(el){
	el.className += ' active';
}
function <?php echo __CLASS__ ?>Inactive(el){
	el.classList.remove('active');
	sessionStorage.setItem('<?php echo __CLASS__ ?>Displace', el.style.cssText);//save rules
}
</script>
<?php
	}
}
